aboutsummaryrefslogtreecommitdiff
path: root/src/pkg/runtime/proc.c
diff options
context:
space:
mode:
authorAram Hăvărneanu <aram@mgk.ro>2014-01-17 17:58:10 +1300
committerJoel Sing <jsing@google.com>2014-01-17 17:58:10 +1300
commita46b43493154bf3c59ce634ee9557a0b273de5ce (patch)
tree7ee539162b796ceb2188659aa6d2947f26e2f461 /src/pkg/runtime/proc.c
parentf8225bdb350f5c7d249f8ed090cf7543901612fa (diff)
downloadgo-a46b43493154bf3c59ce634ee9557a0b273de5ce.tar.xz
runtime: add support for GOOS=solaris
R=alex.brainman, dave, jsing, gobot, rsc CC=golang-codereviews https://golang.org/cl/35990043
Diffstat (limited to 'src/pkg/runtime/proc.c')
-rw-r--r--src/pkg/runtime/proc.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/pkg/runtime/proc.c b/src/pkg/runtime/proc.c
index 064e8cb248..29b6a7c763 100644
--- a/src/pkg/runtime/proc.c
+++ b/src/pkg/runtime/proc.c
@@ -653,9 +653,9 @@ runtime·allocm(P *p)
mp = runtime·cnew(mtype);
mcommoninit(mp);
// In case of cgo, pthread_create will make us a stack.
// Windows will layout sched stack on OS stack.
- if(runtime·iscgo || Windows)
+ if(runtime·iscgo || Solaris || Windows)
mp->g0 = runtime·malg(-1);
else
mp->g0 = runtime·malg(8192);
@@ -653,9 +653,9 @@ runtime·allocm(P *p)
mp = runtime·cnew(mtype);
mcommoninit(mp);
- // In case of cgo, pthread_create will make us a stack.
+ // In case of cgo or Solaris, pthread_create will make us a stack.
// Windows will layout sched stack on OS stack.